<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AddLayer</name>
    <message>
        <location filename="../AddLayerInit.js" line="+2"/>
        <source>&amp;Add Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Dodaj warstwę</translatorcomment>
        <translation>&amp;Dodaj warstwę</translation>
    </message>
    <message>
        <location filename="../AddLayer.js" line="+35"/>
        <source>Layer</source>
        <translation>Warstwa</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Add Layer</source>
        <translation>Dodawanie warstwy</translation>
    </message>
</context>
<context>
    <name>Layer</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+33"/>
        <source>Default color for new layers:</source>
        <translation>Domyślny kolor dla nowych warstw:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Default lineweight for layer 0:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Default color for layer 0:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-45"/>
        <source>Default lineweight for new layers:</source>
        <translation>Domyślna szerokość linii dla nowych warstw:</translation>
    </message>
</context>
</TS>
